<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://ays-pro.com
 * @since      1.0.0
 *
 * @package    Faq_Builder_Ays
 * @subpackage Faq_Builder_Ays/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Faq_Builder_Ays
 * @subpackage Faq_Builder_Ays/admin
 * @author     F.A.Q Builder Team <info@ays-pro.com>
 */
class Faq_Builder_Ays_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;
    
    private $faqs_object;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
        add_filter('set-screen-option', array(__CLASS__, 'set_screen'), 10, 3);

	}

    public function admin_menu_styles(){
        
        echo "<style>
                #adminmenu a.toplevel_page_faq-builder-ays div.wp-menu-image img {
                    width: 32px;
                    padding: 1px 0 0;
                }
            <style>";

    }

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles($hook_suffix) {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Faq_Builder_Ays_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Faq_Builder_Ays_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
        wp_enqueue_style('sweetalert-css', '//cdn.jsdelivr.net/npm/sweetalert2@7.26.29/dist/sweetalert2.min.css', array(), $this->version, 'all');

        wp_enqueue_style($this->plugin_name . '-admin', plugin_dir_url(__FILE__) . 'css/admin.css', array(), $this->version, 'all');
    
        if (false === strpos($hook_suffix, $this->plugin_name))
            return;
    
        wp_enqueue_style('wp-color-picker');
        wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/faq-builder-ays-admin.css', array(), $this->version, 'all' );
        wp_enqueue_style('ays_faq_font_awesome', 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css', array(), $this->version, 'all');
        wp_enqueue_style('ays_faq_bootstrap', plugin_dir_url(__FILE__) . 'css/bootstrap.min.css', array(), $this->version, 'all');
        wp_enqueue_style('ays-qm-select2', '//cdnjs.cloudflare.com/ajax/libs/select2/4.0.0/css/select2.min.css', array(), $this->version, 'all');
        wp_enqueue_style('ays-datatable', '//cdn.datatables.net/1.10.19/css/jquery.dataTables.css', array(), $this->version, 'all');
        wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/faq-builder-ays-admin.css', array(), time()/*$this->version*/, 'all');
         wp_enqueue_style('ays_code_mirror', 'https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.48.4/codemirror.css', array(), $this->version, 'all');
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts($hook_suffix) {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Faq_Builder_Ays_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Faq_Builder_Ays_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
        if (false !== strpos($hook_suffix, "plugins.php")){
        wp_enqueue_script( 'sweetalert-js', '//cdn.jsdelivr.net/npm/sweetalert2@7.26.29/dist/sweetalert2.all.min.js', array('jquery'), $this->version, true );
        wp_enqueue_script($this->plugin_name . '-admin', plugin_dir_url(__FILE__) . 'js/admin.js', array('jquery'), $this->version, true);
        wp_localize_script($this->plugin_name . '-admin',  'faq_admin_ajax', array('ajax_url' => admin_url('admin-ajax.php')));
        }
        if(false === strpos($hook_suffix, $this->plugin_name))
            return;     
        
        wp_enqueue_script('jquery');
        wp_enqueue_script( 'jquery-ui-sortable' );
        
        wp_enqueue_script( "ays_pb_popper", 'https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.14.3/umd/popper.min.js', array( 'jquery' ), $this->version, true );
        wp_enqueue_script( 'select2js', '//cdnjs.cloudflare.com/ajax/libs/select2/4.0.6-rc.0/js/select2.min.js', array('jquery'), $this->version, true );
		wp_enqueue_script( "ays_pb_bootstrap", 'https://stackpath.bootstrapcdn.com/bootstrap/4.1.3/js/bootstrap.min.js', array( 'jquery' ), $this->version, true );
        /*wp_enqueue_script( 'iris', plugin_dir_url(__FILE__) . admin_url( 'js/iris.min.js' ), array( 'jquery-ui-draggable', 'jquery-ui-slider', 'jquery-touch-punch' ), false, 1 );*/
        wp_enqueue_script( $this->plugin_name, plugin_dir_url(__FILE__) . 'js/faq-builder-ays-admin.js', array('jquery', 'wp-color-picker'), $this->version, true);
	}
    public function add_action_links($links){
        /*
        *  Documentation : https://codex.wordpress.org/Plugin_API/Filter_Reference/plugin_action_links_(plugin_file_name)
        */
        $text = __('Settings', $this->plugin_name);
        $settings_link = array(
            '<a href="' . admin_url('admin.php?page=' . $this->plugin_name) . '">' . $text . '</a>'
            );
        return array_merge($settings_link, $links);

    }

      // Code Mirror

        function codemirror_enqueue_scripts($hook) {
        if (false === strpos($hook, $this->plugin_name)){
            return;
        }
        if(function_exists('wp_enqueue_code_editor')){
            $cm_settings['codeEditor'] = wp_enqueue_code_editor(array(
                'type' => 'text/css',
                'codemirror' => array(
                    'inputStyle' => 'contenteditable',
                    'theme' => 'cobalt',
                   
                )
            ));

            wp_enqueue_script('wp-theme-plugin-editor');
            wp_localize_script('wp-theme-plugin-editor', 'cm_settings', $cm_settings);
        
            wp_enqueue_style('wp-codemirror');
        }
    }
    
    /**
     * Register the administration menu for this plugin into the WordPress Dashboard menu.
     *
     * @since    1.0.0
     */
    
    public function add_plugin_admin_menu() {
        /*
         * Add a settings page for this plugin to the Settings menu.
         *
         * NOTE:  Alternative menu locations are available via WordPress administration menu functions.
         *
         *        Administration Menus: http://codex.wordpress.org/Administration_Menus
         *
         */
        
        $hook_faq = add_menu_page( __('F.A.Q. Builder', $this->plugin_name), __('F.A.Q. Builder', $this->plugin_name), 'manage_options', $this->plugin_name, array($this, 'display_plugin_setup_page'), AYS_FAQ_ADMIN_URL . 'images/faq-32x32.png', 6);
        
        add_action( "load-$hook_faq", array( $this, 'screen_option_faq' ) );
        
    

    }  
    
    public function screen_option_faq() {
        $option = 'per_page';
        $args   = [
            'label'   => __('Show faqs per page', $this->plugin_name),
            'default' => 20,
            'option'  => 'faqs_per_page'
        ];

        add_screen_option( $option, $args );
        $this->faqs_object = new Faq_List_Table($this->plugin_name);
    }
    
    public function display_plugin_setup_page() {
        $action = (isset($_GET['action'])) ? sanitize_text_field($_GET['action']) : '';

        switch ($action) {
            case 'add':
                include_once('partials/faq-builder-ays-admin-actions.php');
                break;
            case 'edit':
                include_once('partials/faq-builder-ays-admin-actions.php');
                break;
            default:
                include_once( 'partials/faq-builder-ays-admin-display.php' );
        }
    }
    
    public static function set_screen($status, $option, $value) {
        return $value;
    }

    public function deactivate_plugin_option(){
        $request_value = $_REQUEST['upgrade_plugin'];
        $upgrade_option = get_option('faq_ays_upgrade_plugin','');
        if($upgrade_option === ''){
            add_option('faq_ays_upgrade_plugin',$request_value);
        }else{
            update_option('faq_ays_upgrade_plugin',$request_value);
        }
        echo json_encode(array('option'=>get_option('faq_ays_upgrade_plugin','')));
        wp_die();
    }

    public static function ays_get_faq_user_question( $id ) {
	    global $wpdb;

        $sql = "SELECT user_question FROM {$wpdb->prefix}ays_faqs WHERE id=" . absint( intval( $id ) );

        $user_questions = array();
        $result = $wpdb->get_var($sql);
        if( ! is_null( $result ) ) {
            $user_questions = explode("****", $result); 
        }
        return $user_questions;
    }
}
