<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://ays-pro.com
 * @since             1.0.0
 * @package           Faq_Builder_Ays
 *
 * @wordpress-plugin
 * Plugin Name:       F.A.Q Builder
 * Plugin URI:        https://ays-pro.com
 * Description:       Installing FAQ shows how professional is your work and how attentive you are towards your customers, users, visitors
 * Version:           1.2.6
 * Author:            F.A.Q Builder Team
 * Author URI:        https://ays-pro.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       faq-builder-ays
 * Domain Path:       /languages
 */

// If this file is called directly, abort.

if ( ! defined( 'WPINC' ) ) {
	die;
}

if( ! defined( 'AYS_FAQ_BASE_URL' ) ) {
    define( 'AYS_FAQ_BASE_URL', plugin_dir_url(__FILE__ ) );
}

if( ! defined( 'AYS_FAQ_DIR' ) )
    define( 'AYS_FAQ_DIR', plugin_dir_path( __FILE__ ) );

if( ! defined( 'AYS_FAQ_ADMIN_URL' ) ) {
    define( 'AYS_FAQ_ADMIN_URL', plugin_dir_url(__FILE__ ) . 'admin/' );
}

if( ! defined( 'AYS_FAQ_PUBLIC_URL' ) ) {
    define( 'AYS_FAQ_PUBLIC_URL', plugin_dir_url(__FILE__ ) . 'public/' );
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'FAQ_VERSION', '1.2.6' );
define( 'AYS_FAQ_NAME', 'faq-builder' );
/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-faq-builder-ays-activator.php
 */
function activate_faq_builder_ays() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-faq-builder-ays-activator.php';
	Faq_Builder_Ays_Activator::activate();
}

/**
 * The code that runs after plugin activation.
 * This action is documented in includes/class-simple-google-maps-activator.php
 */
function faq_builder_ays_activation_redirect_method( $plugin ) {
    if( $plugin == plugin_basename( __FILE__ ) ) {
        exit( wp_redirect( admin_url( 'admin.php?page=faq-builder-ays' ) ) );
    }
}
add_action( 'activated_plugin', 'faq_builder_ays_activation_redirect_method' );

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-faq-builder-ays-deactivator.php
 */
function deactivate_faq_builder_ays() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-faq-builder-ays-deactivator.php';
	Faq_Builder_Ays_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_faq_builder_ays' );
register_deactivation_hook( __FILE__, 'deactivate_faq_builder_ays' );
add_action('plugins_loaded', 'activate_faq_builder_ays');

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-faq-builder-ays.php';
require plugin_dir_path( __FILE__ ) . 'faq/faq-builder-block.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_faq_builder_ays() {
    add_action('admin_notices', 'faq_admin_notice');
	$plugin = new Faq_Builder_Ays();
	$plugin->run();

}
function faq_admin_notice(){
    if ( isset($_GET['page']) && strpos($_GET['page'], AYS_FAQ_NAME) !== false ) {
        ?>
             <div class="ays-notice-banner">
                <div class="navigation-bar">
                    <div id="navigation-container">
                        <a class="logo-container" href="http://ays-pro.com/" target="_blank">
                            <img class="logo" src="<?php echo AYS_FAQ_ADMIN_URL . '/images/ays_pro.png'; ?>" alt="AYS Pro logo" title="AYS Pro logo"/>
                        </a>
                        <ul id="menu">
                            <li><a class="ays-btn" href="https://freedemo.ays-pro.com/faq-builder-demo-free/" target="_blank">Demo</a></li>
                            <li><a class="ays-btn" href="https://wordpress.org/support/plugin/faq-builder-ays/" target="_blank">Support Chat</a></li>
                            <li><a class="ays-btn" href="http://ays-pro.com/index.php/contact/" target="_blank">Contact us</a></li>
                        </ul>
                    </div>
                </div>
             </div>
        <?php
    }
}
run_faq_builder_ays();
