<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://ays-pro.com
 * @since      1.0.0
 *
 * @package    Faq_Builder_Ays
 * @subpackage Faq_Builder_Ays/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Faq_Builder_Ays
 * @subpackage Faq_Builder_Ays/public
 * @author     F.A.Q Builder Team <info@ays-pro.com>
 */
class Faq_Builder_Ays_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
        add_shortcode( 'ays_faq', array($this, 'ays_generate_faq') );

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {       
	// 	*
	// 	 * This function is provided for demonstration purposes only.
	// 	 *
	// 	 * An instance of this class should be passed to the run() function
	// 	 * defined in Faq_Builder_Ays_Loader as all of the hooks are defined
	// 	 * in that particular class.
	// 	 *
	// 	 * The Faq_Builder_Ays_Loader will then create the relationship
	// 	 * between the defined hooks and the functions defined in this
	// 	 * class.
		wp_enqueue_style('ays_faq_font_awesome', 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css', array(), $this->version, 'all');
       
             
	}

    public function enqueue_styles_early(){
         wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/faq-builder-ays-public.css', array(), $this->version, 'all' );
    }



    


	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {
		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Faq_Builder_Ays_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Faq_Builder_Ays_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
        
            wp_enqueue_script('jquery'); 
            wp_enqueue_script( "ays_pb_bootstrap", 'https://stackpath.bootstrapcdn.com/bootstrap/4.1.3/js/bootstrap.min.js', array( 'jquery' ), $this->version, true );
            wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/faq-builder-ays-public.js', array( 'jquery' ), $this->version, true );
            /*wp_enqueue_script($this->plugin_name . '-ajax-public', plugin_dir_url(__FILE__) . 'js/quiz-maker-public-ajax.js', array('jquery'), $this->version, true);*/
            wp_localize_script( $this->plugin_name, 'faq_builder_ays_public', array('ajax_url' => admin_url('admin-ajax.php')));
        
	}
    // public function ays_detect_faq_shortcode(){
    //         global $wp_query;   

    //         $ays_posts = $wp_query->posts;

    //         $pattern = get_shortcode_regex();
    //         $pattern = "\[(\[?)(ays_faq)(?![\w-])([^\]\/]*(?:\/(?!\])[^\]\/]*)*?)(?:(\/)\]|\](?:([^\[]*+(?:\[(?!\/\2\])[^\[]*+)*+)\[\/\2\])?)(\]?)";

    //         // echo "<pre>";
    //         // var_dump($pattern);die();
    //         // echo "</pre>";
    //         foreach ( $ays_posts as $post ){
    //         echo $post->ID;            
    //             if ( preg_match_all( '/'. $pattern .'/s', $post->post_content, $matches )
    //                 && array_key_exists( 2, $matches )
    //                 && in_array( 'ays_faq', $matches[2] )
    //             ) {                    
    //                 $this->enqueue_styles();
    //                 $this->enqueue_scripts();
    //                 break; 
    //             }    
    //         }
    //     }

    public function ays_generate_faq( $attr ){
        global $wpdb;
        ob_start();
        $id = ( isset($attr['id']) ) ? absint( intval( $attr['id'] ) ) : null;
        
        $faq = $this->ays_get_faq_by_id($id);
        $style = $faq['style'];
        $options = $faq['options'];

        if(!$faq){
            return "F.A.Q with id {$id} does not exist.";
        }
        $this->enqueue_styles();
        $this->enqueue_scripts();

        $faq_question_array = explode('***', $faq['questions']);
        $faq_answer_array = explode('***', $faq['answers']);

        $customClass = (isset($style['customClass']) && $style['customClass'] != '') ? $style['customClass'] : '';
        $faqWidth = (isset($style['faqWidth']) && $style['faqWidth'] != '') ? $style['faqWidth'] : '';

        if($faqWidth == 0){
            $faqWidth = '100%';
        }else{
            $faqWidth = $faqWidth . 'px' ;
        }


        $faq_view = "<div class='ays-faq-main ". $customClass."'  id='faq_".$faq['id']."'>";
        $faq_view .= "<style>";
        if(isset($style['faqWidth'])){
            $faq_view .= "
                            #faq_".$faq['id']."{
                                width: $faqWidth;
                            } 
                        ";
        }
        if(isset($style['ays_faq_border_width'])){
            $faq_view .= "
                            #faq_".$faq['id']."{
                                border-width: {$style['ays_faq_border_width']}px;
                            } 
                        ";
        }
        if(isset($style['ays_faq_border_style'])){
            $faq_view .= "
                            #faq_".$faq['id']."{
                                border-style: {$style['ays_faq_border_style']};
                            } 
                        ";
        }
        if(isset($style['ays_faq_border_color'])){
            $faq_view .= "
                            #faq_".$faq['id']."{
                                border-color: {$style['ays_faq_border_color']};
                            } 
                        ";
        }
        if(isset($style['bgColor'])){
            $faq_view .= "
                            #faq_".$faq['id']." .ays-faq{
                                background-color:{$style['bgColor']};
                            } 
                        ";
        }
        if(isset($style['faqBorderRadius'])){
            $faq_view .= "
                            #faq_".$faq['id']." .ays-faq{
                               border-radius:{$style['faqBorderRadius']}px;
                            } 
                        ";
        }
        if(isset($style['bgColorQuest'])){
            $faq_view .= "
                            #faq_".$faq['id']." .ays-question{
                                background-color:{$style['bgColorQuest']};
                            } 
                        ";
        }
        if(isset($style['bgColorAnsw'])){
            $faq_view .= "
                            #faq_".$faq['id']." .ays-answer{
                                background-color:{$style['bgColorAnsw']};
                            } 
                        ";
        }
        if(isset($style['titleBgColor'])){
            $faq_view .= "
                            #faq_".$faq['id']." .ays-title{
                                background-color:{$style['titleBgColor']};
                            } 
                        ";
        }
        if(isset($style['textColor'])){
            $faq_view .= "
                            #faq_".$faq['id']."{
                                color:{$style['textColor']};
                            }
                        ";
        }
        if(isset($style['questtextColor'])){
            $faq_view .= "
                            #faq_".$faq['id']." .ays-sub-question, #faq_".$faq['id']." .ays-sub-question .ays_faq_label{
                                color:{$style['questtextColor']};
                            }
                        ";
        }
        if(isset($style['questBorderRadius'])){
            $faq_view .= "
                            #faq_".$faq['id']." .ays-question{
                                border-radius:{$style['questBorderRadius']}px;
                            }
                        ";
        }
        
        if(isset($style['questSpaceBetween'])){
            $faq_view .= "
                             #faq_".$faq['id']." div.ays-border-default:not(:last-child){
                                margin-bottom:{$style['questSpaceBetween']}px;
                            }
                        ";
        }
        if(isset($style['ansHeight']) &&  $style['ansHeight']!=0){
            $faq_view .= "
                             #faq_".$faq['id']." .ays-answer{
                                height:{$style['ansHeight']}px;
                                overflow: auto;
                            }
                        ";
        }
        if(isset($style['ansPadding'])){
            $faq_view .= "
                             #faq_".$faq['id']." .ays-answer{
                                padding-top:{$style['ansPadding']}px;
                                padding-bottom:{$style['ansPadding']}px;
                            }
                        ";
        }
        if(isset($style['answertextColor'])){
            $faq_view .= "
                            #faq_".$faq['id']." .ays-answer{
                                color:{$style['answertextColor']};
                            }
                        ";
        }

        if(isset($style['customCss'])){
            $faq_view .= $style['customCss'];
        }
        if(isset($style['icon_direction']) && $style['icon_direction'] != "none" && isset($style["ays_faq_Icon"])){
            
            if($style["ays_faq_Icon"] == ''){
                $style["ays_faq_Icon"] = 'f13a,f139';
            }
            
            $icons = explode(",", $style["ays_faq_Icon"]); 

            $faq_view .= "
                            #faq_".$faq['id']." .ays-question-default .ays-sub-question::".$style['icon_direction']."{
                                font-family: FontAwesome;
                                content: '\\".$icons[0]."';
                            }
                            
                            #faq_".$faq['id']." .ays-question-default .ays-sub-question.opened-default::".$style['icon_direction']."{
                                font-family: FontAwesome;
                                content: '\\".$icons[1]."';
                            }
                            #faq_".$faq['id']." .ays-question-plusminus .ays-sub-question::".$style['icon_direction']."{
                                font-family: FontAwesome;
                                content: '\\".$icons[0]."';
                            }
                            
                            #faq_".$faq['id']." .ays-question-plusminus .ays-sub-question.opened-plusminus::".$style['icon_direction']."{
                                font-family: FontAwesome;
                                content: '\\".$icons[1]."';
                            }
                            #faq_".$faq['id']." .ays-question-simple .ays-sub-question::".$style['icon_direction']."{
                                font-family: FontAwesome;
                                content: '\\".$icons[0]."';
                                color: ".$style['textColor'].";
                            }
                            
                            #faq_".$faq['id']." .ays-question-simple .ays-sub-question.opened-simple::".$style['icon_direction']."{
                                font-family: FontAwesome;
                                content: '\\".$icons[1]."';
                                color: '".$style['textColor']."';
                            }
                        ";
            if($style['icon_direction'] == "after"){
                $faq_view .= "
                    #faq_".$faq['id']." .ays-sub-question {
                        display: flex;
                        justify-content: space-between;
                    }
                ";
            }
            $faq_view .= "</style>";
        }
        
        

        if(isset($style['style_theme'])){
            $style_theme = $style['style_theme'];
        }
        else{
            $style_theme = "default_arrow";
        }

        if(isset($options["collapseStyle"]))
        {
            $collapseStyle = $options["collapseStyle"];
        }
        else{
            $collapseStyle = "none";
        }

        switch($collapseStyle){
            case "none":
                $faq_CollapseStyle = "noneCollapse";
                break;
            case "accordion";
                $faq_CollapseStyle = "accordionFAQ";
                break;
        }
        $faq_sendQuestionToAdmin = "";
        if(isset($options["sendQuestionToAdmin"]) && $options["sendQuestionToAdmin"] == "on") {
            $faq_sendQuestionToAdmin = "<div class='ays-add-question'>
                <form action='post'>
                    <input type='text' class='ays-add-question-input' name='ays_add_question' placeholder='Add your question' />
                    <button type='button' class='ays-add-question-submit'>".
                __( 'Add', $this->plugin_name) . "</button>
                </form>
                <div style='display: none;' class='ays-add-question-text'>".
                __( 'Your question added', $this->plugin_name) . "</div>
            </div>";
        }
        switch($style_theme){
            case "default_arrow":
                 $faq_view .= "<div class='ays-faq ays-faq-default'>
                        <div class='ays-title ays-title-default'>".stripcslashes(htmlentities($faq['title'])) ."</div>
                        <hr>
                        <div class='ays-description ays-description-default'>".wpautop($faq['description'])."</div>
                        <div class='ays-main' data-id='".$faq_CollapseStyle."'>";
                    foreach($faq_question_array as $key => $question){
                        if($question == ""){
                            $question = "No question";
                        }
                       $faq_view .= "<div class='ays-border-default' id='question_block_".$key."'>
                                        <div class='ays-question ays-question-default'>
                                            <div class='ays-sub-question'>
                                                <label class='ays_faq_label'>".stripcslashes(htmlentities( $question ))."</label>
                                            </div>
                                        </div>
                                        <div class='ays-answer ays-answer-default'>
                                            <div class='ays_modal_element'>".stripcslashes(htmlentities( $faq_answer_array[$key] ))."</div>
                                        </div>
                                    </div>";
                    }
                $faq_view .= $faq_sendQuestionToAdmin."</div></div>";
                break;
            case "plusminus":
                $faq_view .= "<div class='ays-faq ays-faq-plusminus'>
                        <div class='ays-title ays-title-plusminus'>".stripcslashes(htmlentities( $faq['title'] ))."</div>
                        <div class='ays-description ays-description-plusminus'>".wpautop( $faq['description'] )."</div>
                        <div class='ays-main' data-id='".$faq_CollapseStyle."'>";
                    foreach($faq_question_array as $key => $question){
                        if($question == ""){
                            $question = "No question";
                        }
                       $faq_view .= "<div class='ays-border-plusminus ays-border-default' id='question_block_".$key."'>
                                        <div class='ays-question ays-question-plusminus'>
                                            <div class='ays-sub-question'>
                                                <label class='ays_faq_label'>".stripcslashes(htmlentities( $question ))."</label>
                                            </div>
                                        </div>
                                        <div class='ays-answer ays-answer-plusminus'>
                                            <div class='ays_modal_element'>".stripcslashes(htmlentities( $faq_answer_array[$key] ))."</div>
                                        </div>
                                    </div>";
                    }
                 $faq_view .= $faq_sendQuestionToAdmin."</div></div>";
                break;
            case "simple":
                $faq_view .= "<div class='ays-faq ays-faq-simple'>
                        <div class='ays-title ays-title-simple'>" 
                            .stripcslashes(htmlentities( $faq['title'] )).
                        "</div>
                        <div class='ays-description ays-description-simple'>".wpautop( $faq['description'] )."</div>
                        <div class='ays-main' data-id='".$faq_CollapseStyle."'>";
                    foreach($faq_question_array as $key => $question){
                        if($question == ""){
                            $question = "No question";
                        }
                       $faq_view .= "<div class='ays-border-simple ays-border-default' id='question_block_".$key."'>
                                        <div class='ays-question ays-question-simple'>
                                            <div class='ays-sub-question'>
                                                <label class='ays_faq_label'>".stripcslashes(htmlentities( $question ))."</label>
                                            </div>
                                        </div>
                                        <div class='ays-answer ays-answer-simple'>
                                            <div class='ays_modal_element'>".stripcslashes(htmlentities( $faq_answer_array[$key] ))."</div>
                                        </div>
                                    </div>";
                    }
                $faq_view .= $faq_sendQuestionToAdmin."</div></div>";
                break;
        }
        $faq_view .= "</div>";
        return $faq_view;
    }
    
    public function ays_get_faq_by_id( $id ) {
	    global $wpdb;

        $sql = "SELECT * FROM {$wpdb->prefix}ays_faqs WHERE id=" . absint( intval( $id ) );

        $result = $wpdb->get_row($sql, 'ARRAY_A');
        if( ! is_null( $result ) ) {
            $json = $result['style'];
            $result['style'] = json_decode($json, TRUE);
            $json = $result['options'];
            $result['options'] = json_decode($json, TRUE);
    
            return $result;
        }
        return false;
    }
    
    public function ays_get_user_information() {
        if(isset($_REQUEST['userQuestion']) && !empty($_REQUEST['userQuestion'])) {
            global $wpdb;
            $userId = intval($_REQUEST['userId']);
            $results_table = $wpdb->prefix . 'ays_faqs';

            $sql = "SELECT user_question FROM $results_table WHERE id = $userId";
            $question_res = $wpdb->get_var($sql);

            if($question_res == null){
                $user_update_question = stripslashes($_REQUEST["userQuestion"]);
            } else {
                $user_update_question = $question_res."****".stripslashes($_REQUEST["userQuestion"]);
            }
            $results = $wpdb->update(
                $results_table,
                array( 'user_question' => $user_update_question ),
                array( 'id' => $userId ),
                array( '%s' ),
                array( '%d' )
            );
        }

        if(is_user_logged_in()) {
            $output = json_encode(wp_get_current_user());
        } else {
            $output = 'null';
        }
        echo $output;
        wp_die();
    }
}

